// $Id: XmlCommandLineArguments.cpp,v 1.5 2011/11/10 21:38:35 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/


/*!
   \file    XmlCommandLineArguments.cpp
   \brief   Xml interface to time manipulation object
   \author  Hugo Pereira
   \version $Revision: 1.5 $
   \date    $Date: 2011/11/10 21:38:35 $
*/

#include "XmlCommandLineArguments.h"
#include "XmlString.h"



const QString XmlCommandLineArguments::XML_ARGUMENT( "c" );

//______________________________________________________
XmlCommandLineArguments::XmlCommandLineArguments( const QDomElement& element )
{

  Debug::Throw( "XmlCommandLineArguments::XmlCommandLineArguments" );

  // parse children elements
  for(QDomNode child_node = element.firstChild(); !child_node.isNull(); child_node = child_node.nextSibling() )
  {
    QDomElement child_element = child_node.toElement();
    if( child_element.isNull() ) continue;

    if( child_element.tagName() == XML_ARGUMENT ) { push_back( XmlString( child_element.text() ).toText() ); }
    else Debug::Throw() << "XmlCommandLineArguments::XmlCommandLineArguments - unrecognized child: " << child_element.tagName() << endl;

  }

};

//_______________________________________________________
QDomElement XmlCommandLineArguments::domElement( const QString& name, QDomDocument& parent ) const
{
  QDomElement out( parent.createElement( name ) );
  for( const_iterator iter = begin(); iter != end(); ++iter )
  {
    out.
      appendChild( parent.createElement( XML_ARGUMENT ) ).
      appendChild( parent.createTextNode( XmlString( *iter ).toXml() ) );
  }
  return out;
}
